@@ -1,13 +1,11 @@
-package MooseX::Types::DateTime;
-BEGIN {
-  $MooseX::Types::DateTime::AUTHORITY = 'cpan:NUFFIN';
-}
-# git description: MooseX-Types-DateTime-0.06-18-g336ac0e
-$MooseX::Types::DateTime::VERSION = '0.09';
+package MooseX::Types::DateTime; # git description: v0.11-2-gcf49f6d
+# ABSTRACT: L<DateTime> related constraints and coercions for Moose
 
 use strict;
 use warnings;
 
+our $VERSION = '0.12';
+
 use 5.008003;
 use Moose 0.41 ();
 use DateTime 0.4302 ();
@@ -17,9 +15,10 @@ use DateTime::TimeZone 0.95 ();
 
 use MooseX::Types::Moose 0.30 qw/Num HashRef Str/;
 
-use namespace::autoclean;
+use namespace::clean 0.19;
 
 use MooseX::Types 0.30 -declare => [qw( DateTime Duration TimeZone Locale Now )];
+use if MooseX::Types->VERSION >= 0.42, 'namespace::autoclean';
 
 class_type "DateTime";
 class_type "DateTime::Duration";
@@ -88,14 +87,15 @@ __END__
 
 =pod
 
+=encoding UTF-8
+
 =head1 NAME
 
-MooseX::Types::DateTime - L<DateTime> related constraints and coercions for
-Moose
+MooseX::Types::DateTime - L<DateTime> related constraints and coercions for Moose
 
 =head1 VERSION
 
-version 0.09
+version 0.12
 
 =head1 SYNOPSIS
 
@@ -111,6 +111,11 @@ Export Example:
 
     Class->new( time_zone => "Africa/Timbuktu" );
 
+=head1 DESCRIPTION
+
+This module packages several L<Moose::Util::TypeConstraints> with coercions,
+designed to work with the L<DateTime> suite of objects.
+
 =for stopwords Namespaced
 
 Namespaced Example:
@@ -125,11 +130,6 @@ Namespaced Example:
 
     Class->new( time_zone => "Africa/Timbuktu" );
 
-=head1 DESCRIPTION
-
-This module packages several L<Moose::Util::TypeConstraints> with coercions,
-designed to work with the L<DateTime> suite of objects.
-
 =head1 CONSTRAINTS
 
 =over 4
@@ -212,16 +212,54 @@ L<MooseX::Types::DateTime::MoreCoercions>
 
 L<DateTime>, L<DateTimeX::Easy>
 
+=head1 SUPPORT
+
+Bugs may be submitted through L<the RT bug tracker|https://rt.cpan.org/Public/Dist/Display.html?Name=MooseX-Types-DateTime>
+(or L<bug-MooseX-Types-DateTime@rt.cpan.org|mailto:bug-MooseX-Types-DateTime@rt.cpan.org>).
+
+There is also a mailing list available for users of this distribution, at
+L<http://lists.perl.org/list/moose.html>.
+
+There is also an irc channel available for users of this distribution, at
+irc://irc.perl.org/#moose.
+
 =head1 AUTHOR
 
-Yuval Kogman E<lt>nothingmuch@woobling.orgE<gt>
+יובל קוג'מן (Yuval Kogman) <nothingmuch@woobling.org>
 
-John Napiorkowski E<lt>jjn1056 at yahoo.comE<gt>
+=head1 CONTRIBUTORS
 
-=head1 COPYRIGHT
+=for stopwords Karen Etheridge Dagfinn Ilmari Mannsåker Florian Ragwitz John Napiorkowski Shawn M Moore
 
-    Copyright (c) 2008 Yuval Kogman. All rights reserved
-    This program is free software; you can redistribute
-    it and/or modify it under the same terms as Perl itself.
+=over 4
+
+=item *
+
+Karen Etheridge <ether@cpan.org>
+
+=item *
+
+Dagfinn Ilmari Mannsåker <ilmari@ilmari.org>
+
+=item *
+
+Florian Ragwitz <rafl@debian.org>
+
+=item *
+
+John Napiorkowski <jjnapiork@cpan.org>
+
+=item *
+
+Shawn M Moore <sartak@gmail.com>
+
+=back
+
+=head1 COPYRIGHT AND LICENCE
+
+This software is copyright (c) 2008 by יובל קוג'מן (Yuval Kogman).
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
 
 =cut
